@@ -121,23 +121,24 @@ class PubSub:
             name = f'{self.topic_prefix}_{name}'
         cli = self.get_pub_client()
         topic_path = cli.topic_path(self.project_id, name)
-        topics = cli.list_topics(
-            request={
-                'project': f'projects/{self.project_id}'
-            },
-            retry=retry.Retry(deadline=300)
-        )
-        found = False
-        for topic in topics:
-            if topic.name == topic_path:
-                found = True
-                break
-        if not found:
-            topic = cli.create_topic(
+        if self.auto_setup:
+            topics = cli.list_topics(
                 request={
-                    'name': topic_path
-                }
+                    'project': f'projects/{self.project_id}'
+                },
+                retry=retry.Retry(deadline=300)
             )
+            found = False
+            for topic in topics:
+                if topic.name == topic_path:
+                    found = True
+                    break
+            if not found:
+                topic = cli.create_topic(
+                    request={
+                        'name': topic_path
+                    }
+                )
         return topic_path
 
     def callback_subscription(self, message):
@@ -154,10 +155,11 @@ class PubSub:
         topic_path = cli_pub.topic_path(self.project_id, identifier)
         subscription_path = cli_sub.subscription_path(self.project_id, identifier)
 
-        subscriptions = cli_sub.list_subscriptions(
+        subscriptions = cli_sub.get_subscription(
             request={
-                'project': f'projects/{self.project_id}'
-            }
+                'subscription': subscription_path
+            },
+            retry=retry.Retry(deadline=300)
         )
 
         sub = None
@@ -188,10 +190,10 @@ class PubSub:
             response = cli.pull(
                 request={
                     'subscription': request['name'],
-                    'max_messages': self.concurrent_messages
+                    'max_messages': self.concurrent_messages,
+                    'return_immediately': True
                 },
-                retry=retry.Retry(deadline=300),
-                return_immediately=True
+                retry=retry.Retry(deadline=300)
             )
             if len(response.received_messages) > 0:
                 ack_ids = []
